@@ -9,14 +9,16 @@ from .bigmorkal import BigMorkal
 from .caribbeancom import Caribbeancom
 from .deeps import Deeps
 from .dmm import DMM
+from .heyzo import Heyzo
 from .ideapocket import IdeaPocket
 from .javlibrary import JAVLibrary
 from .kmproduce import KMProduce
 from .maxa import MaxA
 from .mgstage import MGStage
+from .onepondo import OnePondo
 from .r18 import R18
 from .s1 import S1
 from .sod import SOD
 from .tenmusume import TenMusume
 
-__version__ = "1.1.1"
+__version__ = "1.1.8"
